ALL_OF_THE_TIME = "all_of_the_time"
CONFINED_TO_BED = "confined_to_bed"
EXTREME_ANXIOUS_DEPRESSED = "extremely_anxious_depressed"
EXTREME_PAIN_DISCOMFORT = "extreme_pain_discomfort"
GOOD_BIT_OF_THE_TIME = "good_bit_of_the_time"
LITTLE_OF_THE_TIME = "little_of_the_time"
MODERATE_ANXIOUS_DEPRESSED = "moderately_anxious_depressed"
MODERATE_PAIN_DISCOMFORT = "moderate_pain_discomfort"
MOST_OF_THE_TIME = "most_of_the_time"
NONE_OF_THE_TIME = "none_of_the_time"
NOT_ANXIOUS_DEPRESSED = "not_anxious_depressed"
NO_PAIN_DISCOMFORT = "no_pain_discomfort"
NO_PROBLEM_SELF_CARE = "no_problems_with_self_care"
NO_PROBLEM_USUAL_ACTIVITIES = "no_problems_performing_usual_activities"
NO_PROBLEM_WALKING = "no_problems_in_walking"
PROBLEM_WASHING_DRESSING = "problems_washing_dressing_myself"
SOME_OF_THE_TIME = "some_of_the_time"
SOME_PROBLEM_USUAL_ACTIVITIES = "some_problems_performing_usual_activities"
SOME_PROBLEM_WALKING = "some_problems_in_walking"
UNABLE_PERFORM_USUAL_ACTIVITIES = "unable_to_perform_usual_activities"
UNABLE_WASH_DRESS = "unable_to_wash_dress_myself"
